#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_CAUINV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_CAUINV_HPP_INCLUDED

#include <nt2/statistics/include/functions/scalar/cauinv.hpp>

#endif
